Struct DefinitionSerializationStrategy
pub struct DefinitionSerializationStrategy;Expand description
A serialization strategy that uses a stable, intermediate representation.
Iterates all registered components via inventory to serialize every component on every entity. The output is human-readable RON with base64-encoded binary component data.
Implementations
impl DefinitionSerializationStrategy
impl DefinitionSerializationStrategy
pub fn new() -> DefinitionSerializationStrategy
pub fn new() -> DefinitionSerializationStrategy
Creates a new DefinitionSerializationStrategy.