RecipeSerializationStrategy

Struct RecipeSerializationStrategy 

pub struct RecipeSerializationStrategy;
A serialization strategy that uses a sequence of commands (SceneRecipe).

This strategy iterates all registered components via inventory to serialize every component on every entity. On deserialization, it looks up the matching registration by type name and decodes.

Implementations



impl RecipeSerializationStrategy

pub fn new() -> RecipeSerializationStrategy

Creates a new instance of the RecipeSerializationStrategy.